==> humhub-1.10.2.tar.gz: humhub-1.10.2/protected/humhub/modules/notification/messages/sv/base.php <==
<?php
return array (
  '<strong>Notification</strong> Overview' => '<strong>Aviseringsöversikt</strong>',
  '<strong>Notification</strong> Settings' => '<strong>Aviseringsinställningar</strong>',
  'Allow desktop notifications by default.' => 'Tillåt skrivbordsaviseringar som standard.',
  'Do you want to reset the settings concerning email summaries for all users?' => 'Vill du återställa inställningarna för e -postsammanfattningar för alla användare?',
  'Do you want to reset the settings concerning notifications for all users?' => 'Vill du återställa inställningarna för aviseringar för alla användare?',
  'Filter' => 'Filtrera',
  'In this view, you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'I den här vyn kan du definiera standardinställningar för dina användare. Dessa inställningar kan dock skrivas över av användarens egna kontoinställningar.',
  'Mark all as seen' => 'Markera alla som lästa',
  'Module Filter' => 'Modulfilter',
  'New' => 'Ny',
  'No notifications found!' => 'Inga aviseringar hittades!',
  'Notifications' => 'Aviseringar',
  'Notifications are sent directly to your users to inform them about new activities in your network.' => 'Aviseringar skickas direkt till dina användare för att informera dem om nya händelser i ditt nätverk.',
  'Notifications are sent instantly to you to inform you about new activities in your network.' => 'Aviseringar skickas direkt till dig för att informera dig om nya händelser i ditt nätverk.',
  'Open the notification dropdown menu' => 'Öppna rullgardinsmenyn för aviseringar',
  'Receive \'New Content\' Notifications for the following spaces' => 'Få aviseringar om "nytt innehåll" från följande nätverk',
  'Receive desktop notifications when you are online.' => 'Ta emot skrivbordsaviseringar när du är online.',
  'Reset for all users' => 'Återställ för alla användare',
  'Reset to defaults' => 'Återställ till grundinställningar',
  'Show all notifications' => 'Visa alla aviseringar',
  'The requested content is not valid or was removed!' => 'Det begärda innehållet är inte giltigt eller har tagits bort!',
  'There are no notifications yet.' => 'Det finns inga aviseringar för tillfället.',
  'This view allows you to configure your notification settings by selecting the desired targets for the given notification categories.' => 'Via den här vyn kan du konfigurera dina aviseringsinställningar. Välj hur du vill att de olika kategorierna för aviseringar ska hanteras.',
  'Type' => 'Typ',
  'View online:' => 'Se online:',
  '{displayName} and {displayName2}' => '{displayName} och {displayName2}',
  '{displayName} and {number} others' => '{displayName} och {number} andra',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/notification/messages/sv/base.php <==
<?php
return array (
  '<strong>Notification</strong> Overview' => '<strong>Aviseringsöversikt</strong>',
  '<strong>Notification</strong> Settings' => '<strong>Aviseringsinställningar</strong>',
  'Allow desktop notifications by default.' => 'Tillåt skrivbordsaviseringar som standard.',
  'Do you want to reset the settings concerning email summaries for all users?' => 'Vill du återställa inställningarna för e -postsammanfattningar för alla användare?',
  'Do you want to reset the settings concerning notifications for all users?' => 'Vill du återställa inställningarna för aviseringar för alla användare?',
  'Filter' => 'Filtrera',
  'In this view, you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'I den här vyn kan du definiera standardinställningar för dina användare. Dessa inställningar kan dock skrivas över av användarens egna kontoinställningar.',
  'Mark all as seen' => 'Markera alla som lästa',
  'Module Filter' => 'Modulfilter',
  'New' => 'Ny',
  'No notifications found!' => 'Inga aviseringar hittades!',
  'Notifications' => 'Aviseringar',
  'Notifications are sent directly to your users to inform them about new activities in your network.' => 'Aviseringar skickas direkt till dina användare för att informera dem om nya händelser i ditt forum.',
  'Notifications are sent instantly to you to inform you about new activities in your network.' => 'Aviseringar skickas direkt till dig för att informera dig om nya händelser i ditt forum.',
  'Open the notification dropdown menu' => 'Öppna rullgardinsmenyn för aviseringar',
  'Receive \'New Content\' Notifications for the following spaces' => 'Få aviseringar om "nytt innehåll" från följande forum',
  'Receive desktop notifications when you are online.' => 'Ta emot skrivbordsaviseringar när du är online.',
  'Reset for all users' => 'Återställ för alla användare',
  'Reset to defaults' => 'Återställ till grundinställningar',
  'Show all notifications' => 'Visa alla aviseringar',
  'The requested content is not valid or was removed!' => 'Det begärda innehållet är inte giltigt eller har tagits bort!',
  'There are no notifications yet.' => 'Det finns inga aviseringar för tillfället.',
  'This view allows you to configure your notification settings by selecting the desired targets for the given notification categories.' => 'Via den här vyn kan du konfigurera dina aviseringsinställningar. Välj hur du vill att de olika kategorierna för aviseringar ska hanteras.',
  'Type' => 'Typ',
  'View online:' => 'Se online:',
  '{displayName} and {displayName2}' => '{displayName} och {displayName2}',
  '{displayName} and {number} others' => '{displayName} och {number} andra',
);
